@@ -8,8 +8,8 @@ use base 'Example::Schema::Result';
 __PACKAGE__->table("employment");
 
 __PACKAGE__->add_columns(
-  id => { data_type => 'integer', is_nullable => 0, is_auto_increment => 1 },
-  label => { data_type => 'varchar', is_nullable => 0, size => '24' },
+  id => { data_type => 'integer', is_nullable => 0, is_auto_increment => 1, tags => ['radio_value'] },
+  label => { data_type => 'varchar', is_nullable => 0, size => '24', tags=>['radio_label'] },
 );
 
 __PACKAGE__->set_primary_key("id");
