@@ -1,24 +1,23 @@
 package Example::View::JS::Account::Edit;
 
-use Moo;
+use CatalystX::Moose;
 use Example::Syntax;
-extends 'Example::View::JS';
+use Example::View::JS;
 
-has 'account' => ( is=>'ro', required=>1 );
+has 'account' => ( is=>'ro', context=>1 );
 
 sub get_form_html($self) {
   my $content = $self->ctx->view(
     'HTML::Account::Form',
     account => $self->account
   )->get_rendered;
-  return $self->escape_javascript($content);
+  return my $escaped = $self->escape_javascript($content);
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
 
 __DATA__
-% my ($self, $c) = @_;
 $(document).on('ajax:success', function(event, data, status, xhr) {
-  $(event.target).html('<%=  $self->get_form_html %>');
+  $(event.target).html('{:get_form_html}');
 });
 
